verticalitytools.get_vertical_moment_starting_with_component
============================================================

.. autofunction:: abjad.tools.verticalitytools.get_vertical_moment_starting_with_component.get_vertical_moment_starting_with_component
